# -*- coding: utf-8 -*-

###############################################################################
#
# UpdateServerCertificate
# Updates the name and/or the path of the specified server certificate.
#
# Python versions 2.6, 2.7, 3.x
#
# Copyright 2014, Temboo Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied. See the License for the specific
# language governing permissions and limitations under the License.
#
#
###############################################################################

from temboo.core.choreography import Choreography
from temboo.core.choreography import InputSet
from temboo.core.choreography import ResultSet
from temboo.core.choreography import ChoreographyExecution

import json

class UpdateServerCertificate(Choreography):

    def __init__(self, temboo_session):
        """
        Create a new instance of the UpdateServerCertificate Choreo. A TembooSession object, containing a valid
        set of Temboo credentials, must be supplied.
        """
        super(UpdateServerCertificate, self).__init__(temboo_session, '/Library/Amazon/IAM/UpdateServerCertificate')


    def new_input_set(self):
        return UpdateServerCertificateInputSet()

    def _make_result_set(self, result, path):
        return UpdateServerCertificateResultSet(result, path)

    def _make_execution(self, session, exec_id, path):
        return UpdateServerCertificateChoreographyExecution(session, exec_id, path)

class UpdateServerCertificateInputSet(InputSet):
    """
    An InputSet with methods appropriate for specifying the inputs to the UpdateServerCertificate
    Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    """
    def set_AWSAccessKeyId(self, value):
        """
        Set the value of the AWSAccessKeyId input for this Choreo. ((required, string) The Access Key ID provided by Amazon Web Services.)
        """
        super(UpdateServerCertificateInputSet, self)._set_input('AWSAccessKeyId', value)
    def set_AWSSecretKeyId(self, value):
        """
        Set the value of the AWSSecretKeyId input for this Choreo. ((required, string) The Secret Key ID provided by Amazon Web Services.)
        """
        super(UpdateServerCertificateInputSet, self)._set_input('AWSSecretKeyId', value)
    def set_NewPath(self, value):
        """
        Set the value of the NewPath input for this Choreo. ((conditional, string) The new path for the server certificate. Include this only if you are updating the server certificate's path.)
        """
        super(UpdateServerCertificateInputSet, self)._set_input('NewPath', value)
    def set_NewServerCertificateName(self, value):
        """
        Set the value of the NewServerCertificateName input for this Choreo. ((conditional, string) The new name for the server certificate. Include this only if you are updating the server certificate's name.)
        """
        super(UpdateServerCertificateInputSet, self)._set_input('NewServerCertificateName', value)
    def set_ResponseFormat(self, value):
        """
        Set the value of the ResponseFormat input for this Choreo. ((optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".)
        """
        super(UpdateServerCertificateInputSet, self)._set_input('ResponseFormat', value)
    def set_ServerCertificateName(self, value):
        """
        Set the value of the ServerCertificateName input for this Choreo. ((required, string) The name for the server certificate. Do not include the path in this value.)
        """
        super(UpdateServerCertificateInputSet, self)._set_input('ServerCertificateName', value)

class UpdateServerCertificateResultSet(ResultSet):
    """
    A ResultSet with methods tailored to the values returned by the UpdateServerCertificate Choreo.
    The ResultSet object is used to retrieve the results of a Choreo execution.
    """

    def getJSONFromString(self, str):
        return json.loads(str)

    def get_Response(self):
        """
        Retrieve the value for the "Response" output from this Choreo execution. (The response from Amazon.)
        """
        return self._output.get('Response', None)

class UpdateServerCertificateChoreographyExecution(ChoreographyExecution):

    def _make_result_set(self, response, path):
        return UpdateServerCertificateResultSet(response, path)
